History
-------

unreleased (YYYY-MM-DD)
+++++++++++++++++++++++

0.1.3 (2020-06-08)
++++++++++++++++++

* (PR #16, 2020-06-08) config: Add support for multiple Python versions to CircleCI
* (PR #18, 2020-06-08) requirements: update 'tox' (test)
* (PR #17, 2020-06-08) Add Python 3.8 support

0.1.2 (2019-07-09)
++++++++++++++++++

* (PR #14, 2019-07-09) requirements: update main depedencies
* (PR #13, 2019-07-09) requirements: update all those for 'test' and 'release'
* (PR #12, 2019-05-14) requirements: update 'urllib3'

0.1.1 (2019-03-07)
++++++++++++++++++

* (PR #9, 2019-03-07) Misc fixes and improvements to config and test setup
* (PR #8, 2019-03-07) Update requirements

0.1.0 (2019-01-24)
++++++++++++++++++

* First implementation.
* First release on PyPI.
